@@ -6,17 +6,17 @@ package Exporter::Proxy;
 
 use v5.12;
 use strict;
-use experimental    qw( smartmatch );
 
 use Carp;
 
-use Symbol  qw( qualify_to_ref );
+use List::Util  qw( first           );
+use Symbol      qw( qualify_to_ref  );
 
 ########################################################################
 # package variables
 ########################################################################
 
-our $VERSION    = '0.08';
+our $VERSION    = '0.09';
 $VERSION = eval $VERSION;
 
 my $disp_list   = 'DISPATCH_OK';
@@ -43,17 +43,13 @@ sub import
     # exported subs.
 
     my $source  = caller;
-
-    my @exportz = ();
-
+    my @exportz = grep { ! /=/ } @_;
     my %argz
-    = do
+    = map
     {
-        my @argz    = grep /=/, @_;
-        @exportz    = grep { ! ( $_ ~~ @argz ) } @_;
-        
-        map { split /=/ } @argz
-    };
+        split /=/, $_, 2 
+    }
+    grep /=/, @_;
 
     # maybe carp about extraneous arguments here?
 
@@ -68,7 +64,7 @@ sub import
     {
         my $list    = qualify_to_ref $disp_list, $source;
 
-        $disp ~~ @exportz 
+        first { $disp eq $_ } @exportz 
         or push @exportz, $disp;
 
         unless( $source->can( $disp ) )
@@ -83,7 +79,7 @@ sub import
                 {
                     my $op      = splice @_, 1, 1;
 
-                    $op ~~ @$sanity
+                    first { $op eq $_ } @$sanity
                     or do
                     {
                         local $"    = ' ';
@@ -173,7 +169,7 @@ sub import
         # empty list => use @exportz.
         # :noexport  => use empty list.
 
-        if( ':noexport' ~~ @_ )
+        if( first { ':noexport' eq $_ } @_ )
         {
             @_  = ();
         }
@@ -189,21 +185,21 @@ sub import
         # resolve these at runtime to account for
         # possible autoloading, etc.
 
-        for( @_ )
+        for my $arg ( @_ )
         {
-            index $_, ':'
+            index $arg, ':'
             or next;
 
-            if( $_ ~~ @exportz )
+            if( first { $arg eq $_ }  @exportz )
             {
-                my $source  = qualify_to_ref $_, $source;
-                my $install = qualify_to_ref $_, $caller;
+                my $source  = qualify_to_ref $arg, $source;
+                my $install = qualify_to_ref $arg, $caller;
 
                 *$install   = *$source;
             }
             else
             {
-                die "Bogus $source: '$_' not exported";
+                die "Bogus $source: '$arg' not exported";
             }
         }
     };
@@ -274,7 +270,7 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
     # subroutine, Bar as an array, or foo may 
     # be overloaded with &foo, %foo, @foo, $foo.
 
-    $value ~~ @Bar
+    $value ~~ $Bar[0]
     or croak "Invalid '$value'";
 
     delete $foo{ somekey }
